# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.key_streams.v1 import key_streams_pb2 as strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2


class KeyStreamsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListKeyStreams = channel.unary_unary(
                '/strmprivacy.api.key_streams.v1.KeyStreamsService/ListKeyStreams',
                request_serializer=strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.ListKeyStreamsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.ListKeyStreamsResponse.FromString,
                )
        self.GetKeyStream = channel.unary_unary(
                '/strmprivacy.api.key_streams.v1.KeyStreamsService/GetKeyStream',
                request_serializer=strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.GetKeyStreamRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.GetKeyStreamResponse.FromString,
                )


class KeyStreamsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListKeyStreams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKeyStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_KeyStreamsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListKeyStreams': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKeyStreams,
                    request_deserializer=strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.ListKeyStreamsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.ListKeyStreamsResponse.SerializeToString,
            ),
            'GetKeyStream': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKeyStream,
                    request_deserializer=strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.GetKeyStreamRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.GetKeyStreamResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.key_streams.v1.KeyStreamsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class KeyStreamsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListKeyStreams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.key_streams.v1.KeyStreamsService/ListKeyStreams',
            strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.ListKeyStreamsRequest.SerializeToString,
            strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.ListKeyStreamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetKeyStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.key_streams.v1.KeyStreamsService/GetKeyStream',
            strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.GetKeyStreamRequest.SerializeToString,
            strmprivacy_dot_api_dot_key__streams_dot_v1_dot_key__streams__pb2.GetKeyStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/agents/v1/batch_exporters_agent_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8strmprivacy/api/agents/v1/batch_exporters_agent_v1.proto\x12\x19strmprivacy.api.agents.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"&\n\x1fGetDesiredBatchExportersRequest:\x03\xf8\x42\x00\"t\n GetDesiredBatchExportersResponse\x12P\n\texporters\x18\x01 \x03(\x0b\x32\x32.strmprivacy.api.entities.v1.ExtendedBatchExporterR\texporters2\xb2\x01\n\x1a\x42\x61tchExportersAgentService\x12\x93\x01\n\x18GetDesiredBatchExporters\x12:.strmprivacy.api.agents.v1.GetDesiredBatchExportersRequest\x1a;.strmprivacy.api.agents.v1.GetDesiredBatchExportersResponseBc\n\x1cio.strmprivacy.api.agents.v1P\x01ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agentsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.agents.v1.batch_exporters_agent_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.strmprivacy.api.agents.v1P\001ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agents'
  _GETDESIREDBATCHEXPORTERSREQUEST._options = None
  _GETDESIREDBATCHEXPORTERSREQUEST._serialized_options = b'\370B\000'
  _GETDESIREDBATCHEXPORTERSREQUEST._serialized_start=159
  _GETDESIREDBATCHEXPORTERSREQUEST._serialized_end=197
  _GETDESIREDBATCHEXPORTERSRESPONSE._serialized_start=199
  _GETDESIREDBATCHEXPORTERSRESPONSE._serialized_end=315
  _BATCHEXPORTERSAGENTSERVICE._serialized_start=318
  _BATCHEXPORTERSAGENTSERVICE._serialized_end=496
# @@protoc_insertion_point(module_scope)
